.. project-template documentation master file, created by
   sphinx-quickstart on Mon Jan 18 14:44:12 2016.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to skope_rules' documentation!
============================================

This project can be useful to anyone who wishes to do supervised
classification under interpretability constraints: explicit logical
rules have to be used for classifying data.
This project is particularly suitable for supervised anomaly detection,
i.e. imbalanced classification.
Application domains include fraud detection, predictive
maintenance, intrusion detection, churn detection...

This project comes with a `skrules` module which contains a single
estimator with unit tests, along with examples and benchmarks.


    .. toctree::
       :maxdepth: 2
       
       api
       auto_examples/index
       ...

See the `README <https://github.com/skope-rules/skope-rules/blob/master/README.md>`_
for more information.











:ref:`genindex`
